
From: Rusty Lynch <rusty.lynch@intel.com>

The following renames arch_init, a kprobes function for performing any
architecture specific initialization, to arch_init_kprobes in order to
cleanup the namespace.

Also, this patch adds arch_init_kprobes to sparc64 to fix the sparc64 kprobes
build from the last return probe patch.

Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 arch/i386/kernel/kprobes.c    |    2 +-
 arch/ia64/kernel/kprobes.c    |    2 +-
 arch/ppc64/kernel/kprobes.c   |    2 +-
 arch/sparc64/kernel/kprobes.c |    5 +++++
 arch/x86_64/kernel/kprobes.c  |    2 +-
 include/linux/kprobes.h       |    2 +-
 kernel/kprobes.c              |    2 +-
 7 files changed, 11 insertions(+), 6 deletions(-)

diff -puN arch/i386/kernel/kprobes.c~fix-namespace-problem-and-sparc64-build arch/i386/kernel/kprobes.c
--- 25/arch/i386/kernel/kprobes.c~fix-namespace-problem-and-sparc64-build	2005-06-29 11:32:48.000000000 -0700
+++ 25-akpm/arch/i386/kernel/kprobes.c	2005-06-29 11:32:48.000000000 -0700
@@ -537,7 +537,7 @@ static struct kprobe trampoline_p = {
 	.pre_handler = trampoline_probe_handler
 };
 
-int __init arch_init(void)
+int __init arch_init_kprobes(void)
 {
 	return register_kprobe(&trampoline_p);
 }
diff -puN arch/ia64/kernel/kprobes.c~fix-namespace-problem-and-sparc64-build arch/ia64/kernel/kprobes.c
--- 25/arch/ia64/kernel/kprobes.c~fix-namespace-problem-and-sparc64-build	2005-06-29 11:32:48.000000000 -0700
+++ 25-akpm/arch/ia64/kernel/kprobes.c	2005-06-29 11:32:48.000000000 -0700
@@ -713,7 +713,7 @@ static struct kprobe trampoline_p = {
 	.pre_handler = trampoline_probe_handler
 };
 
-int __init arch_init(void)
+int __init arch_init_kprobes(void)
 {
 	trampoline_p.addr =
 		(kprobe_opcode_t *)((struct fnptr *)kretprobe_trampoline)->ip;
diff -puN arch/ppc64/kernel/kprobes.c~fix-namespace-problem-and-sparc64-build arch/ppc64/kernel/kprobes.c
--- 25/arch/ppc64/kernel/kprobes.c~fix-namespace-problem-and-sparc64-build	2005-06-29 11:32:48.000000000 -0700
+++ 25-akpm/arch/ppc64/kernel/kprobes.c	2005-06-29 11:32:48.000000000 -0700
@@ -444,7 +444,7 @@ static struct kprobe trampoline_p = {
 	.pre_handler = trampoline_probe_handler
 };
 
-int __init arch_init(void)
+int __init arch_init_kprobes(void)
 {
 	return register_kprobe(&trampoline_p);
 }
diff -puN arch/sparc64/kernel/kprobes.c~fix-namespace-problem-and-sparc64-build arch/sparc64/kernel/kprobes.c
--- 25/arch/sparc64/kernel/kprobes.c~fix-namespace-problem-and-sparc64-build	2005-06-29 11:32:48.000000000 -0700
+++ 25-akpm/arch/sparc64/kernel/kprobes.c	2005-06-29 11:32:48.000000000 -0700
@@ -433,3 +433,8 @@ int longjmp_break_handler(struct kprobe 
 	return 0;
 }
 
+/* architecture specific initialization */
+int arch_init_kprobes(void)
+{
+	return 0;
+}
diff -puN arch/x86_64/kernel/kprobes.c~fix-namespace-problem-and-sparc64-build arch/x86_64/kernel/kprobes.c
--- 25/arch/x86_64/kernel/kprobes.c~fix-namespace-problem-and-sparc64-build	2005-06-29 11:32:48.000000000 -0700
+++ 25-akpm/arch/x86_64/kernel/kprobes.c	2005-06-29 11:32:48.000000000 -0700
@@ -682,7 +682,7 @@ static struct kprobe trampoline_p = {
 	.pre_handler = trampoline_probe_handler
 };
 
-int __init arch_init(void)
+int __init arch_init_kprobes(void)
 {
 	return register_kprobe(&trampoline_p);
 }
diff -puN include/linux/kprobes.h~fix-namespace-problem-and-sparc64-build include/linux/kprobes.h
--- 25/include/linux/kprobes.h~fix-namespace-problem-and-sparc64-build	2005-06-29 11:32:48.000000000 -0700
+++ 25-akpm/include/linux/kprobes.h	2005-06-29 11:32:48.000000000 -0700
@@ -155,7 +155,7 @@ extern void arch_copy_kprobe(struct kpro
 extern void arch_arm_kprobe(struct kprobe *p);
 extern void arch_disarm_kprobe(struct kprobe *p);
 extern void arch_remove_kprobe(struct kprobe *p);
-extern int arch_init(void);
+extern int arch_init_kprobes(void);
 extern void show_registers(struct pt_regs *regs);
 extern kprobe_opcode_t *get_insn_slot(void);
 extern void free_insn_slot(kprobe_opcode_t *slot);
diff -puN kernel/kprobes.c~fix-namespace-problem-and-sparc64-build kernel/kprobes.c
--- 25/kernel/kprobes.c~fix-namespace-problem-and-sparc64-build	2005-06-29 11:32:48.000000000 -0700
+++ 25-akpm/kernel/kprobes.c	2005-06-29 11:32:48.000000000 -0700
@@ -574,7 +574,7 @@ static int __init init_kprobes(void)
 		INIT_HLIST_HEAD(&kretprobe_inst_table[i]);
 	}
 
-	err = arch_init();
+	err = arch_init_kprobes();
 	if (!err)
 		err = register_die_notifier(&kprobe_exceptions_nb);
 
_
